@@ -258,7 +258,7 @@ class WorkflowType(BaseModel):
             task_start_to_close_timeout=decision_tasks_timeout,
         )['runId']
 
-        return WorkflowExecution(self.domain, self, workflow_id, run_id=run_id)
+        return WorkflowExecution(self.domain, workflow_id, run_id=run_id)
 
     def __repr__(self):
         return '<{} domain={} name={} version={} status={}>'.format(
@@ -322,7 +322,7 @@ class WorkflowExecution(BaseModel):
         'decision_tasks_timeout',
     ]
 
-    def __init__(self, domain, workflow_type,
+    def __init__(self, domain,
                  workflow_id, run_id=None,
                  status=STATUS_OPEN, task_list=None,
                  child_policy=None, execution_timeout=None,
@@ -409,14 +409,28 @@ class WorkflowExecution(BaseModel):
         :returns: The workflow execution complete events history
         :rtype: swf.models.event.History
         """
-        event_list = self.connection.get_workflow_execution_history(
+        response = self.connection.get_workflow_execution_history(
             self.domain.name,
             self.run_id,
             self.workflow_id,
             **kwargs
-        )['events']
+        )
 
-        return History.from_event_list(event_list)
+        events = response['events']
+        next_page = response.get('nextPageToken')
+        while next_page is not None:
+            response = self.connection.get_workflow_execution_history(
+                self.domain.name,
+                self.run_id,
+                self.workflow_id,
+                next_page_token=next_page,
+                **kwargs
+            )
+
+            events.extend(response['events'])
+            next_page = response.get('nextPageToken')
+
+        return History.from_event_list(events)
 
     def signal(self, signal_name, input=None, *args, **kwargs):
         """Records a signal event in the workflow execution history and
